﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml">
  <xsl:output method="html" indent="yes" version="4.01"
    doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
    doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"/>
  <xsl:param name="CSSFile1"></xsl:param>
  <xsl:template match="/">
    <html xmlns="http://www.w3.org/1999/xhtml">
      <xsl:attribute name="lang">
        <xsl:value-of select="//Settings//LanguageCode"/>
      </xsl:attribute>
      <xsl:attribute name="dir">
        <xsl:value-of select="//Settings/Direction"/>
      </xsl:attribute>
      <head>
        <meta content="text/html; charset=utf-8" http-equiv="Content-Type" />
        <xsl:choose>
          <xsl:when test="$CSSFile1 !=''">
            <style type="text/css">
              <xsl:value-of select="$CSSFile1"/>
            </style>
          </xsl:when>
          <xsl:otherwise>
            <link rel="stylesheet" type="text/css" href="Workbook-S-140-PublicTalk-WatchtowerStudy-ServiceTalk.css"/>
          </xsl:otherwise>
        </xsl:choose>
        <title>
          <xsl:value-of select="//Labels/Congregation"/>&#160;<xsl:value-of select="//Labels/PTS_WeekendMeetingReportTitle" />
        </title>
      </head>
      <body>
        <div class="containerPage">
          <xsl:for-each select="MeetingWorkBook/Meeting">
            <div class="containerMeeting">
              <xsl:if test="@PageBreak=1">
                <br style="page-break-before: always;"/>
              </xsl:if>
              <xsl:if test="@PageBreak=1 or position()=1">
                <xsl:call-template name="HEADING"/>
              </xsl:if>
              <xsl:if test="@BookmarkId">
                <a>
                  <xsl:attribute name="name">
                    <xsl:value-of select="concat('week', @BookmarkId)"/>
                  </xsl:attribute>
                  <![CDATA[ ]]>
                </a>
              </xsl:if>
              <xsl:call-template name="WEEK"/>

              <xsl:apply-templates select="PUBLICTALK"/>
            </div>
          </xsl:for-each>
        </div>
      </body>
    </html>
  </xsl:template>

  <xsl:template name="WEEK">
    <table class="tableDATE" cellspacing="0" cellpadding="0">
      <xsl:call-template name="SetColumnWidths"/>
      <xsl:if test="@SpecialEvent=1">
        <tr>
          <td class="cellBibleReading" colspan="4">
            <xsl:value-of select="Date"/>
          </td>
        </tr>
        <xsl:apply-templates select="SpecialEvent"/>
      </xsl:if>
      <xsl:if test="@SpecialEvent=0">
        <tr>
          <td class="cellBibleReading" colspan="4">
            <xsl:apply-templates select="PUBLICTALK/MeetingDate" mode="Custom"/>
          </td>
        </tr>
        <xsl:apply-templates select="Note"/>
      </xsl:if>
    </table>
  </xsl:template>

  <xsl:template match="MeetingDate" mode="Custom">
    <xsl:value-of select="@DayFull"/>
    <xsl:text>,&#160;</xsl:text>
    <xsl:value-of select="@Day"/>
    <xsl:text>&#160;</xsl:text>
    <xsl:value-of select="@MonthFull"/>
  </xsl:template>

  <!--Displays the notes (if any)-->
  <xsl:template match="Note">
    <xsl:if test="normalize-space(.) != ''">
      <tr>
        <td class="cellNotes" colspan="4">
          <xsl:value-of select="//Labels/Note"/>:&#160;<xsl:value-of select="."/>
        </td>
      </tr>
    </xsl:if>
  </xsl:template>

  <xsl:template match="SpecialEvent">
    <tr>
      <td class="textSpecialEvent" colspan="4">
        <xsl:value-of select="Event"/> [<xsl:value-of select="Date"/>]
      </td>
    </tr>
    <xsl:if test="normalize-space(Location) != ''">
      <tr>
        <td class="textSpecialEventLocation" colspan="4">
          <xsl:value-of select="Location"/>
        </td>
      </tr>
    </xsl:if>
  </xsl:template>

  <!--Displays heading with a nice double underline-->
  <xsl:template name="HEADING">
    <div class="borderHEADINGOuter">
      <div class="borderHEADINGInner">
        <table class="tableHEADING">
          <tr>
            <td class="textCongregation">
              <xsl:value-of select="//Labels/Congregation"/>
            </td>
            <td class="textTitle">
              <xsl:value-of select="//Labels/PTS_WeekendMeetingReportTitle"/>
            </td>
          </tr>
        </table>
      </div>
    </div>
  </xsl:template>

  <!--Display the end time (using 24 hour format)-->
  <xsl:template match="Time" mode="End">
    <td class="cellTime">
      <xsl:value-of select="@EndTime24"/>
    </td>
  </xsl:template>

  <!--Display the start time (using 24 hour format)-->
  <xsl:template match="Time" mode="Start">
    <td class="cellTime">
      <xsl:value-of select="@StartTime24"/>
    </td>
  </xsl:template>

  <!--Define the column widths for the schedule-->
  <xsl:template name="SetColumnWidths">
    <!--The widths in the column classes will add up to 100%-->
    <xsl:choose>
      <xsl:when test="not(@NumberClasses) or @NumberClasses=1 or self::Meeting">
        <colgroup>
          <col class="columnTime"/>
          <col class="columnTheme1ClassB"/>
          <col class="columnPosition"/>
          <col class="columnName"/>
        </colgroup>
      </xsl:when>
      <xsl:when test="@NumberClasses=2">
        <colgroup>
          <col class="columnTime"/>
          <col class="columnTheme2ClassB"/>
          <col class="columnPosition"/>
          <col class="columnName"/>
          <col class="columnName"/>
        </colgroup>
      </xsl:when>
      <xsl:when test="@NumberClasses=3">
        <colgroup>
          <col class="columnTime"/>
          <col class="columnTheme3ClassB"/>
          <col class="columnPosition"/>
          <col class="columnName"/>
          <col class="columnName"/>
          <col class="columnName"/>
        </colgroup>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="PUBLICTALK">
    <table class="tableWeekend">
      <colgroup>
        <col class ="columnTime"/>
        <col class ="columnPublicTalk"/>
        <col class ="columnName"/>
      </colgroup>
      <tr>
        <td class ="cellWEEKEND" colspan="2">
          <div class="textWEEKEND" style="float:left">
            <xsl:value-of select="//Labels/PTS_Talk"/>
          </div>
          <div class="floatRight">
            <xsl:value-of select="//Labels/PTS_Chairman"/>:
          </div>
        </td>
        <td class="cellName">
          <xsl:value-of select="Assignments/Chairman"/>
        </td>
      </tr>
      <xsl:apply-templates select="HomeTalk"/>
      <xsl:apply-templates select="AwayTalk"/>
      <xsl:apply-templates select="Assignments"/>
    </table>
  </xsl:template>

  <!--Displays the home talk speaker details-->
  <xsl:template match="HomeTalk">
    <tr>
      <xsl:apply-templates select="Time" mode="End"/>
      <td class="cellWEEKENDText">
        <div class="floatRight">
          <xsl:value-of select="//Labels/PTS_Congregation"/>:
        </div>
        <span class="textPTSLabel">
          <xsl:value-of select="//Labels/PTS_Speaker"/>:
        </span>
        &#160;<span class="textPTSValue">
          <xsl:value-of select="Speaker"/>
        </span>
      </td>
      <td class="cellName">
        <xsl:value-of select="Congregation"/>
      </td>
    </tr>
    <tr>
      <td class="cellWEEKENDText" colspan="3">
        <span class="textPTSLabel">
          <xsl:value-of select="//Labels/PTS_Theme"/>:
        </span>
        &#160;<span class="textPTSValue">
          <xsl:value-of select="Theme"/>
        </span>
      </td>
    </tr>
    <tr>
      <td colspan="2">
        <div class="floatRight">
          <xsl:value-of select="//Labels/PTS_Hospitality"/>:
        </div>
      </td>
      <td  class="cellName">
        <xsl:value-of select="../Assignments/Hospitality"/>
      </td>
    </tr>
  </xsl:template>

  <xsl:template match="AwayTalk">
    <tr>
      <td class="cellWEEKENDText" colspan="3">
        <span class="textPTSLabel">
          <xsl:choose>
            <!--We only support 2 away speakers. We could just use one label-->
            <xsl:when test="position()=1">
              <xsl:value-of select="//Labels/PTS_AwaySpeaker1"/>:
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="//Labels/PTS_AwaySpeaker2"/>:
            </xsl:otherwise>
          </xsl:choose>
        </span>
        &#160;<span class="textPTSValue">
          <xsl:value-of select="Speaker"/>&#160;(<xsl:value-of select="Congregation"/>)
        </span>
      </td>
    </tr>
  </xsl:template>

  <!--Displays the Watchtower study, conductor and reader-->
  <xsl:template match="Assignments">
    <tr>
      <td style="padding-left: 1mm;" colspan="3">
        <div class="WTHeading">
          <xsl:value-of select="//Labels/PTS_WTStudy"/>
        </div>
      </td>
    </tr>
    <tr>
      <xsl:apply-templates select="WatchtowerStudy/Time" mode="End"/>
      <td class="cellWEEKENDText">
        <span class="textPTSValue">
          <div class="floatRight">
            <xsl:value-of select="//Labels/PTS_WTConductor"/>:
          </div>
          <xsl:value-of select="WatchtowerStudy/Theme"/>
        </span>
      </td>
      <td class="cellName">
        <xsl:value-of select="Conductor"/>
      </td>
    </tr>
    <xsl:choose>
      <!--This is not a circuit visit so show the reader-->
      <xsl:when test="../preceding-sibling::*[1]/@CircuitVisit=0">
        <tr>
          <td class="cellWEEKENDText" colspan="2">
            <div class="floatRight">
              <xsl:value-of select="//Labels/PTS_WTReader"/>:
            </div>
          </td>
          <td class="cellName">
            <xsl:value-of select="Reader"/>
          </td>
        </tr>
      </xsl:when>
      <!--This is a circuit visit so show the final service talk-->
      <xsl:otherwise>
        <tr>
          <td style="padding-left: 1mm;" colspan="3">
            <div class="ServiceTalkHeading">
              <xsl:value-of select="//Labels/PTS_ServiceTalk"/>
            </div>
          </td>
        </tr>
        <tr>
          <xsl:apply-templates select="ServiceTalk/Time" mode="End"/>
          <td class="cellWEEKENDText">
            <span class="textPTSLabel">
              <xsl:value-of select="//Labels/PTS_Theme"/>:
            </span>
            &#160;<span class="textPTSValue">
              <xsl:value-of select="ServiceTalk/Theme"/>
            </span>
          </td>
          <td class="cellName">
            <xsl:value-of select="../preceding-sibling::*[1]/CircuitVisit/LACItem/Name"/>
          </td>
        </tr>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
</xsl:stylesheet>